/* $Workfile: OtxSlicD.h $   $Revision: 12 $    $Modtime: 5/17/05 2:01p $  */
#ifndef OTX_SLIC_DEF_H
#define OTX_SLIC_DEF_H
/*******************************************************************************

  @doc PublicHwApi OtxSlicD

  Copyright (C) 2005 Odin TeleSystems Inc., All Rights Reserved

  OTX Generic Hardware Driver API

  @module
  OtxSlicD | Constants, Macros, and Types for the Analog Phone Functions

  @contents2
  OtxSlicD.h |

  @index enum struct type | OtxSlicD

  @contents2
  OTX SLIC Line Interface Device Constants, Macros, and Types |

  @head3 OtxSlicXXX Macro, Constant, and Type Reference |

  @index enum struct type | OtxSlicD

*******************************************************************************/

#ifdef __cplusplus
extern "C" {
#endif

#define OTX_SLIC_SIZE_OF_USER_ID       15
#define OTX_SLIC_SIZE_OF_PHONE_ID      10
#define OTX_SLIC_SIZE_OF_DATE_TIME_ID   8
// Make sure buffer size includes room for NULL
#define OTX_SLIC_SIZE_OF_USER_BUF      OTX_SLIC_SIZE_OF_USER_ID + 1
#define OTX_SLIC_SIZE_OF_PHONE_BUF     OTX_SLIC_SIZE_OF_PHONE_ID + 1
#define OTX_SLIC_SIZE_OF_DATE_TIME_BUF OTX_SLIC_SIZE_OF_DATE_TIME_ID + 1 

#define OTX_SLIC_RING_DELAY            200L

/*******************************************************************************
  @enum
    Driver state machine call states for Slic device. 
*******************************************************************************/ 
enum OtxSlicDeviceCallState { 
  OTX_SLIC_CS_INITIALIZING                = 0,  // @emem SLIC device is being initialized
  OTX_SLIC_CS_CALIBRATE                   = 1,  // @emem SLIC device is being calibrated
  OTX_SLIC_CS_MAKE_OFFHOOK                = 2,  // @emem SLIC device was already off-hook when a second off-hook interrupt was detected
  OTX_SLIC_CS_ONHOOK                      = 3,  // @emem SLIC device is on-hook
  OTX_SLIC_CS_OFFHOOK                     = 4,  // @emem SLIC device is off-hook
  OTX_SLIC_CS_FIRST_RING                  = 5,  // @emem SLIC device has received the first ring interrupt
  OTX_SLIC_CS_DEFERED_CALLBACK_PROGRAMMED = 6,  // @emem SLIC device is performing a backgroud task
  OTX_SLIC_CS_CALLER_ID                   = 7,  // @emem SLIC device is sending a caller ID
  OTX_SLIC_CS_RINGING                     = 8,  // @emem SLIC device has continued recieving the ring interrupt
  OTX_SLIC_CS_DTMF_TRANSITION             = 9,  // @emem SLIC device detected a DTMF 

  OTX_SLIC_CS_END_OF_STATES               = 10, // @emem The application can start his own states starting from this value

};

typedef enum OtxSlicDeviceCallState OtxSlicDeviceCallState;


/*******************************************************************************
  @enum
    SLIC Notify Causes. 
*******************************************************************************/
enum OtxSlicEventCodeE {
  OTX_SLIC_OSC1_INACTIVE         =  1,  // @emem Oscillator 1 Active Timer Interrupt
  OTX_SLIC_OSC1_ACTIVE           =  2,  // @emem Oscillator 1 Inactive Timer Interrupt
  OTX_SLIC_OSC2_INACTIVE         =  3,  // @emem Oscillator 2 Active Timer Interrupt
  OTX_SLIC_OSC2_ACTIVE           =  4,  // @emem Oscillator 2 Inactive Timer Interrupt
  OTX_SLIC_RING_INACTIVE         =  5,  // @emem Ringing Active Timer Interrupt
  OTX_SLIC_RING_ACTIVE           =  6,  // @emem Ringing Inactive Timer Interrupt.
  OTX_SLIC_PULSE_INACTIVE        =  7,  // @emem Pulse Metering Active Timer Interrupt
  OTX_SLIC_PULSE_ACTIVE          =  8,  // @emem Pulse Metering Inactive Timer Interrupt
  OTX_SLIC_RING_TRIP             =  9,  // @emem Ring Trip Interrupt
  OTX_SLIC_LOOP_STATE            = 10,  // @emem Loop Closure Transition Interrupt
  OTX_SLIC_PWR_ALARM_PQ1         = 11,  // @emem Power Alarm Q1 Interrupt
  OTX_SLIC_PWR_ALARM_PQ2         = 12,  // @emem Power Alarm Q2 Interrupt
  OTX_SLIC_PWR_ALARM_PQ3         = 13,  // @emem Power Alarm Q3 Interrupt
  OTX_SLIC_PWR_ALARM_PQ4         = 14,  // @emem Power Alarm Q4 Interrupt
  OTX_SLIC_PWR_ALARM_PQ5         = 15,  // @emem Power Alarm Q5 Interrupt
  OTX_SLIC_PWR_ALARM_PQ6         = 16,  // @emem Power Alarm Q6 Interrupt
  OTX_SLIC_DTMF_DETECT           = 17,  // @emem DTMF Tone Detected 
  OTX_SLIC_INDIRECT_ACCESS_RDY   = 18,  // @emem Indirect Register Access Serviced
  OTX_SLIC_ERROR_CM_CAL          = 19,  // @emem Common Mode Calibration Error

  OTX_SLIC_RING_INACTIVE_CONT    = 20,  // @emem Continue Ringing Active Timer
  OTX_SLIC_ON_HOOK               = 21,  // @emem Slic indicates ONHOOK condition
  OTX_SLIC_OFF_HOOK              = 22,  // @emem Slic indicates OFFHOOK condition

};

typedef enum OtxSlicEventCodeE OtxSlicEventCodeE;


/*******************************************************************************
  @enum 
    SLIC Device Attributes
*******************************************************************************/
enum OtxSlicDeviceAttributesE {
  OTX_ATTR_SLIC_RELAY_CONTROL       = OTX_ATTR_END + 0, // @emem (OTX_ATTRIB_BOOL) Read/Write. For OTX_DEVICE_LI_SLIC devices. 
                                                        // <nl> This attribute defaults to OTX_FALSE, which means that the 
                                                        // fail-over relay for this SLIC is in a pass-through state, and the SLIC
                                                        // is effectively disconnected from the POTS line.
                                                        // Setting this attribute to OTX_TRUE will engage the fail-over relay,
                                                        // which will break the pass-through state, and connect the FXS to the 
                                                        // the POTS line.

  OTX_ATTR_SLIC_RING_TYPE_CONTROL    = OTX_ATTR_END + 1, // @emem (OTX_ATTRIB_UINT32) Read/Write. For OTX_DEVICE_LI_SLIC devices. 
                                                        // <nl> This attribute defaults to OTX_SLIC_CFG_SET_RING_0, which means 
                                                        // that the SLIC device will use the standard ring cadence for the given
                                                        // country.

  OTX_ATTR_SLIC_POTS_CFG_SET         = OTX_ATTR_END + 2, // @emem (OTX_ATTRIB_UINT32) Read/Write. Set the Country Specific 
                                                        // configuration set for the POTS line interface (e.g. DC characteristics, 
                                                        // ringer impedance, filter coefficients, etc). 

  OTX_ATTR_SLIC_POTS_COMPRESSION_SET = OTX_ATTR_END + 3, // @emem (OTX_ATTRIB_UINT32) Read/Write. Set the Country Specific 
                                                        // configuration set for the POTS line compression tyep (e.g. u-Law, A-Law  
                                                        // or Linear "OtxSlicCmpCfgSetE"). 

  OTX_ATTR_SLIC_END                  = OTX_ATTR_END + 4
};

typedef enum OtxSlicDeviceAttributesE OtxSlicDeviceAttributesE;


/*******************************************************************************
  @enum 
    SLIC Country Specific configuration sets (to be used with the <e OtxSlicDeviceAttributesE.OTX_ATTR_SLIC_CFG_SET> attribute
*******************************************************************************/
enum OtxSlicCfgSetE {
  OTX_SLIC_CFG_SET_USA       = 0,  // @emem SLIC configuration for USA
  OTX_SLIC_CFG_SET_GERMANY   = 1,  // @emem SLIC configuration for Germany
  OTX_SLIC_CFG_SET_UK        = 2,  // @emem SLIC configuration for United Kingdom
  OTX_SLIC_CFG_SET_FRANCE    = 3,  // @emem SLIC configuration for France
  OTX_SLIC_CFG_SET_AUSTRALIA = 4,  // @emem SLIC configuration for Australia
  OTX_SLIC_CFG_SET_JAPAN     = 5,  // @emem SLIC configuration for Japan
};
typedef enum OtxSlicCfgSetE OtxSlicCfgSetE;


/*******************************************************************************
  @enum 
    SLIC Ring Type configuration sets (to be used with the <e OtxSlicDeviceAttributesE.OTX_ATTR_SLIC_CFG_SET> attribute
*******************************************************************************/
enum OtxSlicRingCfgSetE {
  OTX_SLIC_CFG_SET_RING_0    = 0,  // @emem SLIC configuration for standard ring
  OTX_SLIC_CFG_SET_RING_1    = 1,  // @emem SLIC configuration for non standard
};
typedef enum OtxSlicRingCfgSetE OtxSlicRingCfgSetE;


/*******************************************************************************
  @enum 
    SLIC line compression (to be used with the <e OtxSlicDeviceAttributesE.OTX_ATTR_SLIC_CFG_SET> attribute
*******************************************************************************/
enum OtxSlicCmpCfgSetE {
  OTX_SLIC_CMP_SET_U_LAW    = 0,  // @emem SLIC u-Law (system default)
  OTX_SLIC_CMP_SET_A_LAW    = 1,  // @emem SLIC A-Law
  OTX_SLIC_CMP_SET_LINEAR   = 2,  // @emem SLIC Linear 
};
typedef enum OtxSlicCmpCfgSetE OtxSlicCmpCfgSetE;


#ifdef __cplusplus
}  // extern "C"
#endif



/*******************************************************************************

  Copyright (C) Odin TeleSystems Inc., 2005

  All rights reserved. No part of this computer program may be reproduced,
  stored in any retrieval system, or transmitted, in any form or by any
  means, electronic, mechanical, photocopying, recording, or otherwise,
  without the prior written permission of Odin TeleSystems Inc., or without
  a permission stipulated in the agreement/contract under which this computer
  program was supplied.

*******************************************************************************/
#endif    // OTX_SLIC_DEF_H
